.. pySignalScope documentation master file, created by
   sphinx-quickstart on Wed May  8 10:34:43 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pySignalScope's documentation!
============================================

.. toctree::
   :maxdepth: 6
   :caption: Contents:

   intro



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
